@@ -277,7 +277,7 @@ class Cases:
                 title_cell = f'{self.title_column_letters["用例名称"]}{row_index}'
                 precondition_cell = f'{self.title_column_letters["前置条件"]}{row_index}'
                 steps_cell = f'{self.title_column_letters["用例步骤"]}{row_index}'
-                expected_cell = f'{self.title_column_letters["预期结果"]}{row_index}'
+                expectation_cell = f'{self.title_column_letters["预期结果"]}{row_index}'
                 priority_cell = f'{self.title_column_letters["用例等级"]}{row_index}'
                 case_id_cell = f'{self.title_column_letters["case_id"]}{row_index}'
                 case_id = self.excel.tapd.post_tapd_case(
@@ -286,7 +286,7 @@ class Cases:
                     name=self.case_ws[title_cell].value,
                     precondition=html_format(self.case_ws[precondition_cell].value or ''),
                     steps=html_format(self.case_ws[steps_cell].value or ''),
-                    expectation=html_format(self.case_ws[expected_cell].value or ''),
+                    expectation=html_format(self.case_ws[expectation_cell].value or ''),
                     priority=html_format(self.case_ws[priority_cell].value or ''),
                     creator=creator,
                     custom_field_1=self.case_ws[custom_field_1_cell].value or '',
@@ -335,11 +335,14 @@ class BVTCases(Cases):
             time.sleep(0.5)  # 强制先暂停 0.5s, 避免太快进度条没刷出来就结束了，体验提升 50%
             for row_index in bar:
                 developer_cell = f'{self.title_column_letters["开发人员"]}{row_index}'
-                if self.case_ws[developer_cell].value:
+                priority_cell = f'{self.title_column_letters["用例等级"]}{row_index}'
+                if self.case_ws[developer_cell].value and self.case_ws[priority_cell].value == '高':
+                    custom_field_1_cell = f'{self.title_column_letters["一级模块"]}{row_index}'
+                    custom_field_2_cell = f'{self.title_column_letters["二级模块"]}{row_index}'
                     title_cell = f'{self.title_column_letters["用例名称"]}{row_index}'
                     precondition_cell = f'{self.title_column_letters["前置条件"]}{row_index}'
                     steps_cell = f'{self.title_column_letters["用例步骤"]}{row_index}'
-                    expected_cell = f'{self.title_column_letters["预期结果"]}{row_index}'
+                    expectation_cell = f'{self.title_column_letters["预期结果"]}{row_index}'
                     story_cell = f'{self.title_column_letters["需求"]}{row_index}'
                     task_id_cell = f'{self.title_column_letters["task_id"]}{row_index}'
 
@@ -351,9 +354,11 @@ class BVTCases(Cases):
                         story_id=stories_map.get(self.case_ws[story_cell].value),
                         iteration_id=self.iteration_meta_info['iteration_id'],
                         description=template.render(
+                            custom_field_1=self.case_ws[custom_field_1_cell].value or '',
+                            custom_field_2=self.case_ws[custom_field_2_cell].value or '',
                             precondition=self.case_ws[precondition_cell].value or '',
                             case_steps=self.case_ws[steps_cell].value or '',
-                            expected=self.case_ws[expected_cell].value or ''
+                            expectation=self.case_ws[expectation_cell].value or ''
                         )
                     )
                     if task_id:
